<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>指示器样式</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>时尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>经典模式</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>居中模式</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>一直显示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>一直隐藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智能隐藏</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>任务栏设置</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>禁用自由调节</translation>
    </message>
</context>
</TS>